@@ -14,6 +14,7 @@ impl<T, const N: usize> AsMut<T> for StaticVec<T, {N}> {
   ///internally and converts it to one.
   #[inline(always)]
   fn as_mut(&mut self) -> &mut T {
+    //I don't know how useful this impl actually is. We'll see I guess.
     assert!(self.length > 0);
     unsafe { self.as_mut_ptr().as_mut().unwrap() }
   }
@@ -25,6 +26,7 @@ impl<T, const N: usize> AsRef<T> for StaticVec<T, {N}> {
   ///internally and converts it to one.
   #[inline(always)]
   fn as_ref(&self) -> &T {
+    //I don't know how useful this impl actually is. We'll see I guess.
     assert!(self.length > 0);
     unsafe { self.as_ptr().as_ref().unwrap() }
   }
@@ -44,6 +46,23 @@ impl<T, const N: usize> AsRef<[T]> for StaticVec<T, {N}> {
   }
 }
 
+impl<T: Clone, const N: usize> Clone for StaticVec<T, {N}> {
+  #[inline]
+  fn clone(&self) -> Self {
+    let mut res = Self::new();
+    for i in 0..self.length {
+      unsafe {
+        res
+          .data
+          .get_unchecked_mut(i)
+          .write(self.data.get_unchecked(i).get_ref().clone());
+      }
+    }
+    res.length = self.length;
+    res
+  }
+}
+
 impl<T: Debug, const N: usize> Debug for StaticVec<T, {N}> {
   #[inline(always)]
   fn fmt(&self, f: &mut Formatter) -> Result {
